@@ -19,6 +19,7 @@ from .widgets import (
     SpinBox,
     TextEdit,
     TimeEdit,
+    ToolBar,
     get_text_width,
 )
 
@@ -46,6 +47,7 @@ __all__ = [
     "Slider",
     "SpinBox",
     "TextEdit",
+    "ToolBar",
     "get_text_width",
     "show_file_dialog",
 ]
