@@ -71,11 +71,15 @@ _SIMPLE_TYPES = {
     datetime.datetime: widgets.DateTimeEdit,
     range: widgets.RangeEdit,
     slice: widgets.SliceEdit,
-    list: widgets.ListEdit,
+    Sequence[pathlib.Path]: widgets.FileEdit,
     tuple: widgets.TupleEdit,
+    Sequence: widgets.ListEdit,
     os.PathLike: widgets.FileEdit,
 }
 
+_ADDITIONAL_KWARGS: dict[type, dict[str, Any]] = {
+    Sequence[pathlib.Path]: {"mode": "rm"}
+}
 
 def match_type(type_: Any, default: Any | None = None) -> WidgetTuple | None:
     """Check simple type mappings."""
@@ -86,10 +90,10 @@ def match_type(type_: Any, default: Any | None = None) -> WidgetTuple | None:
         return widgets.ProgressBar, {"bind": lambda widget: widget, "visible": True}
 
     if type_ in _SIMPLE_TYPES:
-        return _SIMPLE_TYPES[type_], {}
+        return _SIMPLE_TYPES[type_], _ADDITIONAL_KWARGS.get(type_, {})
     for key in _SIMPLE_TYPES.keys():
         if safe_issubclass(type_, key):
-            return _SIMPLE_TYPES[key], {}
+            return _SIMPLE_TYPES[key], _ADDITIONAL_KWARGS.get(key, {})
 
     if type_ in (types.FunctionType,):
         return widgets.FunctionGui, {"function": default}
@@ -99,16 +103,6 @@ def match_type(type_: Any, default: Any | None = None) -> WidgetTuple | None:
     if choices is not None:  # it's a Literal type
         return widgets.ComboBox, {"choices": choices, "nullable": nullable}
 
-    # sequence of paths
-    if safe_issubclass(origin, Sequence):
-        args = get_args(type_)
-        if len(args) == 1 and safe_issubclass(args[0], pathlib.Path):
-            return widgets.FileEdit, {"mode": "rm"}
-        elif safe_issubclass(origin, list):
-            return widgets.ListEdit, {}
-        elif safe_issubclass(origin, tuple):
-            return widgets.TupleEdit, {}
-
     if safe_issubclass(origin, Set):
         for arg in get_args(type_):
             if get_origin(arg) is Literal:
