@@ -51,7 +51,11 @@ def _inject_tooltips_from_docstrings(
     if not docstring:
         return
 
-    doc_params = {p.arg_name: p.description for p in parse(docstring).params}
+    doc_params: dict[str, str | None] = {
+        p.arg_name: p.description for p in parse(docstring).params
+    }
+    if not doc_params:
+        return
 
     # deal with the (numpydocs) case when there are multiple parameters separated
     # by a comma
@@ -60,7 +64,6 @@ def _inject_tooltips_from_docstrings(
             for split_key in k.split(","):
                 doc_params[split_key.strip()] = v
             del doc_params[k]
-
     for name, description in doc_params.items():
         # this is to catch potentially bad arg_name parsing in docstring_parser
         # if using napoleon style google docstringss
@@ -424,10 +427,13 @@ class FunctionGui(Container, Generic[_P, _R]):
         if obj_id not in self._bound_instances:
             method = getattr(obj.__class__, self._function.__name__)
             p0 = next(iter(inspect.signature(method).parameters))
-            prior, self._param_options = self._param_options, {
-                p0: {"bind": obj},
-                **self._param_options,
-            }
+            prior, self._param_options = (
+                self._param_options,
+                {
+                    p0: {"bind": obj},
+                    **self._param_options,
+                },
+            )
             try:
                 self._bound_instances[obj_id] = self.copy()
             finally:
