@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Callable
 
 from psygnal import Signal, SignalInstance
 
@@ -9,8 +9,12 @@ from magicgui.types import Undefined, _Undefined
 from ._value_widget import ValueWidget
 
 if TYPE_CHECKING:
+    from typing_extensions import Unpack
+
     from magicgui.widgets import protocols
 
+    from ._widget import WidgetKwargs
+
 
 class ButtonWidget(ValueWidget[bool]):
     """Widget with a value, Wraps a widget implementing the ButtonWidgetProtocol.
@@ -33,7 +37,7 @@ class ButtonWidget(ValueWidget[bool]):
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     **base_widget_kwargs : Any
         All additional keyword arguments are passed to the base
-        [`magicgui.widgets.Widget`][] constructor.
+        [`magicgui.widgets.Widget`][magicgui.widgets.Widget] constructor.
     """
 
     _widget: protocols.ButtonWidgetProtocol
@@ -48,9 +52,11 @@ class ButtonWidget(ValueWidget[bool]):
         value: bool | _Undefined = Undefined,
         *,
         text: str | None = None,
+        icon: str | None = None,
+        icon_color: str | None = None,
         bind: bool | Callable[[ValueWidget], bool] | _Undefined = Undefined,
         nullable: bool = False,
-        **base_widget_kwargs: Any,
+        **base_widget_kwargs: Unpack[WidgetKwargs],
     ) -> None:
         if text and base_widget_kwargs.get("label"):
             from warnings import warn
@@ -68,6 +74,8 @@ class ButtonWidget(ValueWidget[bool]):
             value=value, bind=bind, nullable=nullable, **base_widget_kwargs
         )
         self.text = (text or self.name).replace("_", " ")
+        if icon:
+            self.set_icon(icon, icon_color)
 
     @property
     def options(self) -> dict:
@@ -89,3 +97,6 @@ class ButtonWidget(ValueWidget[bool]):
     def clicked(self) -> SignalInstance:
         """Alias for changed event."""
         return self.changed
+
+    def set_icon(self, value: str | None, color: str | None = None) -> None:
+        self._widget._mgui_set_icon(value, color)
