@@ -117,7 +117,7 @@ class ContainerWidget(Widget, _OrientationMixin, MutableSequence[WidgetVar]):
         )
         super().__init__(**base_widget_kwargs)
         self.extend(widgets)
-        self.parent_changed.connect(self.reset_choices)
+        self.native_parent_changed.connect(self.reset_choices)
         self._initialized = True
         self._unify_label_widths()
 
@@ -141,12 +141,10 @@ class ContainerWidget(Widget, _OrientationMixin, MutableSequence[WidgetVar]):
         object.__setattr__(self, name, value)
 
     @overload
-    def __getitem__(self, key: int | str) -> WidgetVar:
-        ...
+    def __getitem__(self, key: int | str) -> WidgetVar: ...
 
     @overload
-    def __getitem__(self, key: slice) -> MutableSequence[WidgetVar]:
-        ...
+    def __getitem__(self, key: slice) -> MutableSequence[WidgetVar]: ...
 
     def __getitem__(
         self, key: int | str | slice
