@@ -3,16 +3,19 @@ from __future__ import annotations
 import builtins
 from abc import ABC, abstractmethod
 from math import ceil, log10
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Tuple, TypeVar, Union, cast
-from warnings import warn
+from typing import TYPE_CHECKING, Callable, Iterable, Tuple, TypeVar, Union, cast
 
 from magicgui.types import Undefined, _Undefined
 
 from ._value_widget import ValueWidget
 
 if TYPE_CHECKING:
+    from typing_extensions import Unpack
+
     from magicgui.widgets import protocols
 
+    from ._widget import WidgetKwargs
+
 T = TypeVar("T", int, float, Tuple[Union[int, float], ...])
 DEFAULT_MIN = 0.0
 DEFAULT_MAX = 1000.0
@@ -42,7 +45,7 @@ class RangedWidget(ValueWidget[T]):
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     **base_widget_kwargs : Any
         All additional keyword arguments are passed to the base
-        [`magicgui.widgets.Widget`][] constructor.
+        [`magicgui.widgets.Widget`][magicgui.widgets.Widget] constructor.
     """
 
     _widget: protocols.RangedWidgetProtocol
@@ -56,20 +59,8 @@ class RangedWidget(ValueWidget[T]):
         step: float | _Undefined | None = Undefined,
         bind: T | Callable[[ValueWidget], T] | _Undefined = Undefined,
         nullable: bool = False,
-        **base_widget_kwargs: Any,
-    ) -> None:  # sourcery skip: avoid-builtin-shadow
-        for key in ("maximum", "minimum"):
-            if key in base_widget_kwargs:
-                warn(
-                    f"The {key!r} keyword arguments has been changed to {key[:3]!r}. "
-                    "In the future this will raise an exception\n",
-                    FutureWarning,
-                    stacklevel=2,
-                )
-                if key == "maximum":
-                    max = base_widget_kwargs.pop(key)  # noqa: A001
-                else:
-                    min = base_widget_kwargs.pop(key)  # noqa: A001
+        **base_widget_kwargs: Unpack[WidgetKwargs],
+    ) -> None:
         # value should be set *after* min max is set
         super().__init__(
             bind=bind,  # type: ignore
@@ -196,7 +187,7 @@ class RangedWidget(ValueWidget[T]):
 
 
 class TransformedRangedWidget(RangedWidget[float], ABC):
-    """Widget with a contstrained value. Wraps RangedWidgetProtocol.
+    """Widget with a constrained value. Wraps RangedWidgetProtocol.
 
     This can be used to map one domain of numbers onto another, useful for creating
     things like LogSliders.  Subclasses must reimplement ``_value_from_position`` and
@@ -226,7 +217,7 @@ class TransformedRangedWidget(RangedWidget[float], ABC):
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     **base_widget_kwargs : Any
         All additional keyword arguments are passed to the base
-        [`magicgui.widgets.Widget`][] constructor.
+        [`magicgui.widgets.Widget`][magicgui.widgets.Widget] constructor.
     """
 
     _widget: protocols.RangedWidgetProtocol
@@ -242,7 +233,7 @@ class TransformedRangedWidget(RangedWidget[float], ABC):
         step: int = 1,
         bind: T | Callable[[ValueWidget], T] | _Undefined = Undefined,
         nullable: bool = False,
-        **base_widget_kwargs: Any,
+        **base_widget_kwargs: Unpack[WidgetKwargs],
     ) -> None:
         self._min = min
         self._max = max
