@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, Tuple, Union
+from typing import TYPE_CHECKING, Callable, Tuple, Union
 
 from magicgui.types import Undefined, _Undefined
 
@@ -8,11 +8,15 @@ from ._mixins import _OrientationMixin
 from ._ranged_widget import MultiValueRangedWidget, RangedWidget, T
 
 if TYPE_CHECKING:
+    from typing_extensions import Unpack
+
     from magicgui.widgets import protocols
 
+    from ._widget import WidgetKwargs
+
 
 class SliderWidget(RangedWidget[T], _OrientationMixin):
-    """Widget with a contstrained value and orientation. Wraps SliderWidgetProtocol.
+    """Widget with a constrained value and orientation. Wraps SliderWidgetProtocol.
 
     Parameters
     ----------
@@ -44,7 +48,7 @@ class SliderWidget(RangedWidget[T], _OrientationMixin):
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     **base_widget_kwargs : Any
         All additional keyword arguments are passed to the base
-        [`magicgui.widgets.Widget`][] constructor.
+        [`magicgui.widgets.Widget`][magicgui.widgets.Widget] constructor.
     """
 
     _widget: protocols.SliderWidgetProtocol
@@ -61,7 +65,7 @@ class SliderWidget(RangedWidget[T], _OrientationMixin):
         tracking: bool = True,
         bind: T | Callable[[protocols.ValueWidgetProtocol], T] | _Undefined = Undefined,
         nullable: bool = False,
-        **base_widget_kwargs: Any,
+        **base_widget_kwargs: Unpack[WidgetKwargs],
     ) -> None:
         base_widget_kwargs["backend_kwargs"] = {
             "readout": readout,
