@@ -10,8 +10,12 @@ from magicgui.types import Undefined, _Undefined
 from ._widget import Widget
 
 if TYPE_CHECKING:
+    from typing_extensions import Unpack
+
     from magicgui.widgets import protocols
 
+    from ._widget import WidgetKwargs
+
 T = TypeVar("T")
 
 
@@ -32,7 +36,7 @@ class ValueWidget(Widget, Generic[T]):
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     **base_widget_kwargs : Any
         All additional keyword arguments are passed to the base
-        [`magicgui.widgets.Widget`][] constructor.
+        [`magicgui.widgets.Widget`][magicgui.widgets.Widget] constructor.
     """
 
     _widget: protocols.ValueWidgetProtocol
@@ -45,7 +49,7 @@ class ValueWidget(Widget, Generic[T]):
         *,
         bind: T | Callable[[ValueWidget], T] | _Undefined = Undefined,
         nullable: bool = False,
-        **base_widget_kwargs: Any,
+        **base_widget_kwargs: Unpack[WidgetKwargs],
     ) -> None:
         self._nullable = nullable
         self._bound_value = bind
@@ -97,7 +101,7 @@ class ValueWidget(Widget, Generic[T]):
         return self._widget._mgui_set_value(value)
 
     def __repr__(self) -> str:
-        """Return representation of widget of instsance."""
+        """Return representation of widget of instance."""
         try:
             val = self.value if self._bound_value is Undefined else self._bound_value
             return (
