@@ -33,7 +33,14 @@ def test_doc_code_cells(fname):
         exec(cell, globalns)
 
 
-example_files = [f for f in glob("examples/*.py") if "napari" not in f]
+EXAMPLES = Path(__file__).parent.parent / "docs" / "examples"
+# leaving out image only because finding the image file in both
+# tests and docs is a pain...
+# range_slider has periodic segfaults
+EXCLUDED = {"napari", "image", "range_slider"}
+example_files = [
+    str(f) for f in EXAMPLES.rglob("*.py") if all(x not in str(f) for x in EXCLUDED)
+]
 
 # if os is Linux and python version is 3.9 and backend is PyQt5
 LINUX = sys.platform.startswith("linux")
@@ -65,28 +72,3 @@ def test_examples(fname, monkeypatch):
         if "waveform" in fname:
             type_map._type_map._TYPE_DEFS.pop(int, None)
             type_map._type_map._TYPE_DEFS.pop(float, None)
-
-
-@pytest.mark.skipif(sys.version_info < (3, 11), reason="requires python3.11")
-def test_setuppy():
-    """Ensure that setup.py matches pyproject deps.
-
-    (setup.py is only there for github)
-    """
-    import ast
-
-    import tomllib
-
-    setup = Path(__file__).parent.parent / "setup.py"
-    pyproject = Path(__file__).parent.parent / "pyproject.toml"
-    settxt = setup.read_text(encoding="utf-8")
-    deps = ast.literal_eval(settxt.split("install_requires=")[-1].split("]")[0] + "]")
-
-    with open(pyproject, "rb") as f:
-        data = tomllib.load(f)
-
-    projdeps = set(data["project"]["dependencies"])
-    assert projdeps == set(deps)
-
-    min_req = data["project"]["optional-dependencies"]["min-req"]
-    assert {k.replace(">=", "==") for k in projdeps} == set(min_req)
