@@ -9,7 +9,7 @@ from unittest.mock import Mock
 
 import pytest
 from qtpy.QtCore import Qt
-from qtpy.QtWidgets import QScrollArea
+from qtpy.QtWidgets import QScrollArea, QWidget
 
 from magicgui import magicgui, register_type, type_map, widgets
 from magicgui.signature import MagicSignature, magic_signature
@@ -83,8 +83,7 @@ def test_overriding_widget_type():
 
     # also without type annotation
     @magicgui(a={"widget_type": "LogSlider"})
-    def g(a):
-        ...
+    def g(a): ...
 
     assert isinstance(g.a, widgets.LogSlider)
 
@@ -173,8 +172,7 @@ def test_dropdown_list_from_enum():
         Air = 1.0003
 
     @magicgui
-    def func(arg: Medium = Medium.Water):
-        ...
+    def func(arg: Medium = Medium.Water): ...
 
     assert func.arg.value == Medium.Water
     assert isinstance(func.arg, widgets.ComboBox)
@@ -186,8 +184,7 @@ def test_dropdown_list_from_choices():
     CHOICES = ["Oil", "Water", "Air"]
 
     @magicgui(arg={"choices": CHOICES})
-    def func(arg="Water"):
-        ...
+    def func(arg="Water"): ...
 
     assert func.arg.value == "Water"
     assert isinstance(func.arg, widgets.ComboBox)
@@ -196,8 +193,7 @@ def test_dropdown_list_from_choices():
     with pytest.raises(ValueError):
         # the default value must be in the list
         @magicgui(arg={"choices": ["Oil", "Water", "Air"]})
-        def func(arg="Silicone"):
-            ...
+        def func(arg="Silicone"): ...
 
 
 def test_dropdown_list_from_callable():
@@ -208,8 +204,7 @@ def test_dropdown_list_from_callable():
         return CHOICES
 
     @magicgui(arg={"choices": get_choices})
-    def func(arg="Water"):
-        ...
+    def func(arg="Water"): ...
 
     assert func.arg.value == "Water"
     assert isinstance(func.arg, widgets.ComboBox)
@@ -489,11 +484,26 @@ def test_register_return_callback():
         _RETURN_CALLBACKS.pop(Base)
 
 
-# @pytest.mark.skip(reason="need to rethink how to test this")
-# def test_parent_changed(qtbot, magic_func):
-#     """Test that setting MagicGui parent emits a signal."""
-#     with qtbot.waitSignal(magic_func.parent_changed, timeout=1000):
-#         magic_func.native.setParent(None)
+def test_parent_changed(qtbot, magic_func: widgets.FunctionGui) -> None:
+    """Test that setting a backend parent emits a signal."""
+    wdg = QWidget()
+    qtbot.addWidget(wdg)
+
+    mock = Mock()
+    magic_func.native_parent_changed.connect(mock)
+    with qtbot.waitSignal(magic_func.native_parent_changed, timeout=1000):
+        magic_func.native.setParent(wdg)
+
+    # the backend parent is emitted
+    mock.assert_called_once_with(wdg)
+
+    with qtbot.waitSignal(magic_func.native_parent_changed, timeout=1000):
+        magic_func.native.setParent(None)
+
+    mock.assert_called_with(None)
+
+    with pytest.warns(FutureWarning, match="'parent_changed' signal has been renamed"):
+        magic_func.parent_changed  # noqa: B018
 
 
 def test_function_binding():
@@ -729,8 +739,7 @@ def test_empty_function():
     """Test that a function with no params works."""
 
     @magicgui(call_button=True)
-    def f():
-        ...
+    def f(): ...
 
     f.show()
 
@@ -767,8 +776,7 @@ def test_none_defaults():
 
 def test_update_and_dict():
     @magicgui
-    def test(a: int = 1, y: str = "a"):
-        ...
+    def test(a: int = 1, y: str = "a"): ...
 
     assert test.asdict() == {"a": 1, "y": "a"}
 
@@ -784,8 +792,7 @@ def test_update_and_dict():
 
 def test_update_on_call():
     @magicgui
-    def test(a: int = 1, y: str = "a"):
-        ...
+    def test(a: int = 1, y: str = "a"): ...
 
     assert test.call_count == 0
     test(a=10, y="b", update_widget=True)
@@ -839,16 +846,14 @@ def test_curry():
 
 def test_scrollable():
     @magicgui(scrollable=True)
-    def test_scrollable(a: int = 1, y: str = "a"):
-        ...
+    def test_scrollable(a: int = 1, y: str = "a"): ...
 
     assert test_scrollable.native is not test_scrollable.root_native_widget
     assert not isinstance(test_scrollable.native, QScrollArea)
     assert isinstance(test_scrollable.root_native_widget, QScrollArea)
 
     @magicgui(scrollable=False)
-    def test_nonscrollable(a: int = 1, y: str = "a"):
-        ...
+    def test_nonscrollable(a: int = 1, y: str = "a"): ...
 
     assert test_nonscrollable.native is test_nonscrollable.root_native_widget
     assert not isinstance(test_nonscrollable.native, QScrollArea)
