@@ -2,7 +2,7 @@ import datetime
 import inspect
 from enum import Enum
 from pathlib import Path
-from typing import Optional, Tuple
+from typing import List, Optional, Tuple
 from unittest.mock import MagicMock, patch
 
 import pytest
@@ -287,6 +287,20 @@ def test_unhashable_choice_data():
     combo.close()
 
 
+def test_ambiguous_eq_choice_data():
+    """Test that providing choice data with an ambiguous equal operation is ok."""
+    import numpy as np
+
+    combo = widgets.ComboBox()
+    assert not combo.choices
+    combo.choices = (("a", np.array([0, 0, 0])), ("b", np.array([1, 2, 3])))
+    assert len(combo.choices) == 2
+    assert np.all(combo.choices[0] == [0, 0, 0])
+    assert np.all(combo.choices[1] == [1, 2, 3])
+
+    combo.close()
+
+
 def test_bound_values():
     """Test that we can bind a "permanent" value override to a parameter."""
 
@@ -833,8 +847,6 @@ def test_pushbutton_icon(backend: str):
 
 def test_list_edit():
     """Test ListEdit."""
-    from typing import List
-
     mock = MagicMock()
 
     list_edit = widgets.ListEdit(value=[1, 2, 3])
@@ -886,6 +898,8 @@ def test_list_edit():
     assert mock.call_count == 7
     mock.assert_called_with([2, 1])
 
+
+def test_list_edit_only_values():
     @magicgui
     def f1(x=[2, 4, 6]):  # noqa: B006
         pass
@@ -894,6 +908,7 @@ def test_list_edit():
     assert f1.x._args_type is int
     assert f1.x.value == [2, 4, 6]
 
+def test_list_edit_annotations():
     @magicgui
     def f2(x: List[int]):
         pass
